@@ -1,12 +1,12 @@
-from pgkit.application.utils import execute_sync
+from pgkit.application.utils import execute_sync, to_number
 
 
 class Postgres:
     def __init__(self, name, host, port, version, dbname, username, password, slot):
         self.name = name
         self.host = host
-        self.port = port
-        self.version = version
+        self.port = to_number(port)
+        self.version = to_number(version)
         self.dbname = dbname
         self.username = username
         self.password = password
@@ -17,5 +17,5 @@ class Postgres:
                      env=[('PGPASSWORD', self.password)])
 
     def force_switch_wal(self):
-        pg_command = 'select * from pg_switch_xlog()' if float(self.version) < 10 else 'select * from pg_switch_wal()'
+        pg_command = 'select * from pg_switch_xlog()' if self.version < 10 else 'select * from pg_switch_wal()'
         self.run_cmd(pg_command)
