@@ -73,7 +73,7 @@ class Replica(Postgres):
                   f' -p {self.master.port}' \
                   f' -D {self.db_location}' \
                   f' -U {self.master.username}' \
-                  f' -v --checkpoint=fast'
+                  f' -v --checkpoint=fast --progress'
         execute_sync(command, env=[('PGPASSWORD', self.master.password)])
 
         print('change owner to postgres')
@@ -100,8 +100,12 @@ class Replica(Postgres):
             standby_port=self.port,
         )
 
-        file_location = f'/etc/postgresql/{self.version}/{self.name}/postgresql.conf' if float(self.version) >= 12 \
+        file_location = f'/etc/postgresql/{self.version}/{self.name}/postgresql.conf' if self.version >= 12 \
             else f'{self.db_location}/recovery.conf'
 
         write_file(file_location, recovery_config)
         chown(file_location, 'postgres')
+
+        if self.version >= 12:
+            touch_file(f'{self.db_location}/recovery.signal')
+            touch_file(f'{self.db_location}/standby.signal')
